<?php
/**
 * @license
 * Copyright 2018 TruongLuu. All Rights Reserved.
 */

namespace Truonglv\StickyTimer\Entity;

use XF\Entity\Thread;
use XF\Mvc\Entity\Entity;
use XF\Mvc\Entity\Structure;
use Truonglv\StickyTimer\Listener;

/**
 * Class Sticky
 * @package Truonglv\StickyTimer\Entity
 *
 * @property int thread_id
 * @property int expire_date
 *
 * @property \XF\Entity\Thread|null Thread
 */
class Sticky extends Entity
{
    public function isExpired()
    {
        if ($this->expire_date === 0) {
            return false;
        }

        return $this->expire_date <= \XF::$time;
    }

    public static function getStructure(Structure $structure)
    {
        $structure->table = 'xf_tl_thread_sticky_timer';
        $structure->primaryKey = 'thread_id';
        $structure->shortName = 'Truonglv\StickyTimer:Sticky';

        $structure->columns = [
            'thread_id' => ['type' => self::UINT, 'required' => true],
            'expire_date' => ['type' => self::UINT, 'default' => 0]
        ];

        $structure->relations = [
            'Thread' => [
                'type' => self::TO_ONE,
                'entity' => 'XF:Thread',
                'conditions' => 'thread_id',
                'primary' => true
            ]
        ];

        $structure->options = [
            'remove_sticky' => true
        ];

        return $structure;
    }

    protected function _postDelete()
    {
        /** @var Thread|null $thread */
        $thread = $this->Thread;

        if ($this->getOption('remove_sticky')
            && $thread !== null
            && Listener::isEnableNode($thread->node_id)
        ) {
            $thread->sticky = false;
            $thread->save(false);
        }
    }
}
